noizu_sendgrid v2.1.0 SendGrid.Templates View Source

Link to this section Summary

Link to this section Types

Link to this type t() View Source
t() :: %SendGrid.Templates{
  metadata: SendGrid.MetaData.t() | nil,
  templates: [SendGrid.Template.t()]
}

Link to this section Functions

Link to this function delete(template, options \\ []) View Source
delete(
  String.t() | SendGrid.DynamicTemplate.t() | Sendgrid.LegacyTemplate.t(),
  SendGrid.query()
) ::
  :ok | {:error, [String.t()]} | {:error, String.t()}
Link to this function get(identifier, options \\ []) View Source
Link to this function list(options \\ []) View Source
list(SendGrid.query()) :: t() | {:error, [String.t()]} | {:error, String.t()}
Link to this function new(response, options) View Source
new(SendGrid.Response.t(), SendGrid.query()) ::
  Templates.t() | {:error, [String.t()]} | {:error, String.t()}
Link to this function next(self, options \\ []) View Source
next(t(), SendGrid.query()) ::
  Templates.t() | {:error, [String.t()]} | {:error, String.t()}
Link to this function patch_options(options \\ []) View Source
patch_options(SendGrid.query()) :: SendGrid.query()

Param injector does not handle list data, overriding here to allow user to pass in array or desired generations.